lhc_graphMeasuresForParameterChange_overTime <-
function(FILEPATH,PARAMETERS,MEASURES,MEASURE_SCALE,LHCSUMMARYFILENAME,CORCOEFFSOUTPUTFILE,TIMEPOINTS,TIMEPOINTSCALE)
{
	# FOR ALL TIMEPOINTS
	for(n in 1:length(TIMEPOINTS))
	{
		TIMEPOINTANALYSED<-TIMEPOINTS[n]
		CORCOEFFSFILENAME<-paste(CORCOEFFSOUTPUTFILE,"_",TIMEPOINTANALYSED,sep="")
		LHCSUMMARYFILENAMEFULL<-paste(LHCSUMMARYFILENAME,"_",TIMEPOINTANALYSED,sep="")

		lhc_graphMeasuresForParameterChange(FILEPATH,PARAMETERS,MEASURES,MEASURE_SCALE,CORCOEFFSFILENAME,LHCSUMMARYFILENAMEFULL,TIMEPOINTANALYSED,TIMEPOINTSCALE)
	}
}

